Release 1.3.2
=============

This is a minor release that adds functionality that tries to handle mixed bytes and strings gracefully.

Changes for developers
----------------------

 - Tries to handle mixed bytes and strings gracefully.
